@@ -19,12 +19,12 @@ class APIException(PAException):
     """
 
     def __init__(self, msg: str, endpoint: str = None, status_code: int = None) -> None:
-        self._msg = msg
+        self.message = msg
         self.endpoint = endpoint
         self.status_code = status_code
 
     def __str__(self):
-        return f'{self._msg} ({self.status_code}, {self.endpoint})'
+        return f'{self.message} ({self.status_code}, {self.endpoint})'
 
 
 class ClientException(PAException):
